# Number of CPUs to use:

ncpus <- 130


# Make table of settings: 

niter <- 1015
nvarvec <- c(2,10,200,20000)
methods <- c("DLDA", "ElNet", "kNN", "pkNN", "penLogReg", 
  "RanFor", "shrinkLDA", "SVMlinear", "SVMradial", "cboost")

scenariogrid <- expand.grid(method=methods, nvar=nvarvec, 
  iter=1:niter, stringsAsFactors = FALSE)
scenariogrid <- scenariogrid[,ncol(scenariogrid):1]

set.seed(1234)
seeds <- sample(1000:10000000, size=niter)

scenariogrid$seed <- rep(seeds, each=length(methods)*length(nvarvec))


# Source necessary functions:

source("./FishingPaper/Functions/SnowfallFunctions.R")



# Load 'snowfall'-Package for parallel computation:
require("snowfall")


# Initiate cluster:
sfInit(parallel=TRUE, cpus=ncpus, type = "MPI")

# Export all objects to the CPUs:
sfExportAll()

# Perform computations:
RealdataResults <- sfLapply(1:nrow(scenariogrid), function(z) performAnalysis(z))

# Stop the cluster:
sfStop()


# Save results:

save(RealdataResults, file="./FishingPaper/Results/RealdataResults.Rda")

# Clear the workspace:
rm(list=ls()); gc()
